@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-window.c 6275 2008-05-10 09:38:26Z pborelli $
+ * $Id: gedit-window.c 6485 2008-09-05 08:51:00Z icq $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -1232,7 +1232,7 @@ update_recent_files_menu (GeditWindow *window)
 
 		/* gtk_recent_info_get_uri_display (info) is buggy and
 		 * works only for local files */
-		uri = gedit_utils_format_uri_for_display (gtk_recent_info_get_uri (info));
+		uri = gedit_utils_uri_for_display (gtk_recent_info_get_uri (info));
 		ruri = gedit_utils_replace_home_dir_with_tilde (uri);
 		g_free (uri);
 
@@ -1380,7 +1380,7 @@ create_menu_bar_and_toolbar (GeditWindow *window,
 	window->priv->quit_action_group = action_group;
 
 	/* now load the UI definition */
-	gtk_ui_manager_add_ui_from_file (manager, GEDIT_UI_DIR "gedit-ui.xml", &error);
+	gtk_ui_manager_add_ui_from_file (manager, GEDIT_UIDIR "gedit-ui.xml", &error);
 	if (error != NULL)
 	{
 		g_warning ("Could not merge gedit-ui.xml: %s", error->message);
@@ -3616,6 +3616,15 @@ _gedit_window_set_saving_session_state (GeditWindow *window,
 	}
 }
 
+/**
+ * gedit_window_get_tab_from_location:
+ * @window: a #GeditWindow
+ * @location: a #GFile
+ *
+ * Gets the #GeditTab that matches with the given @location.
+ *
+ * Returns: the #GeditTab that matches with the given @location.
+ */
 GeditTab *
 gedit_window_get_tab_from_location (GeditWindow *window,
 				    GFile       *location)
